@@ -1,15 +1,13 @@
 # (c) Nelen & Schuurmans.  GPL licensed, see LICENSE.rst.
-# -*- coding: utf-8 -*-
-from __future__ import unicode_literals
-from __future__ import print_function
 
 
-class DataSource(object):
+class DataSource:
     """
     Datasource containing a 'dict' like object
     acting as the main datasource for the gridadmin
     models.
     """
+
     meta = None
     _source = None
 
@@ -20,8 +18,8 @@ class DataSource(object):
     def keys(self):
         keys = list(self._source.keys())
         # Append meta to keys if not present
-        if 'meta' not in keys:
-            keys.append('meta')
+        if "meta" not in keys:
+            keys.append("meta")
         return keys
 
     def set(self, name, value):
@@ -29,12 +27,12 @@ class DataSource(object):
 
     def get(self, name):
         # meta is special
-        if name == 'meta':
+        if name == "meta":
             return self.meta
         return self._source.get(name)
 
     def __getitem__(self, name):
         # meta is special
-        if name == 'meta':
+        if name == "meta":
             return self.meta
         return self._source[name]
