@@ -1,10 +1,7 @@
 # (c) Nelen & Schuurmans.  GPL licensed, see LICENSE.rst.
-# -*- coding: utf-8 -*-
-from __future__ import unicode_literals
-from __future__ import print_function
 
-from __future__ import absolute_import
 import json
+
 import numpy as np
 
 
@@ -27,6 +24,6 @@ class NumpyEncoder(json.JSONEncoder):
         elif isinstance(obj, np.ndarray):
             return obj.tolist()
         if isinstance(obj, bytes):
-            return obj.decode('utf-8')
+            return obj.decode("utf-8")
         else:
-            return super(NumpyEncoder, self).default(obj)
+            return super().default(obj)
